.. epicsmacrolib documentation master file, created by
   sphinx-quickstart on Tue May 22 13:13:05 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to epicsmacrolib's documentation!
===========================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples

.. toctree::
   :maxdepth: 1
   :caption: Links
   :hidden:

   Github Repository <https://github.com/pcdshub/epicsmacrolib>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
